@@ -26,6 +26,7 @@ from typing import (
     Tuple,
     TypeVar,
     Union,
+    cast,
 )
 
 import clu
@@ -98,6 +99,8 @@ class BaseCommand(
         A silent command will call the actor ``write`` method with ``silent=True``,
         which will update the internal model and record all the output replies but
         will not write them to the users.
+    time_limit
+        Time out the command if it has been running for this long.
     loop
         The event loop.
 
@@ -115,6 +118,7 @@ class BaseCommand(
         call_now: bool = False,
         default_keyword: str = "text",
         silent: bool = False,
+        time_limit: float | None = None,
         loop: Optional[asyncio.AbstractEventLoop] = None,
     ):
 
@@ -122,7 +126,9 @@ class BaseCommand(
         self.consumer_id = consumer_id
         self.command_id = command_id
 
-        self.actor = actor
+        # Casting here so that we can type Command[SomeActor] and not have to
+        # assert command.actor every time.
+        self.actor = cast(Actor_co, actor)
         self.parent = parent
 
         self.silent = silent
@@ -147,6 +153,14 @@ class BaseCommand(
             call_now=call_now,
         )
 
+        self._timer_handler = None
+        if time_limit:
+            self._timer_handler = asyncio.get_running_loop().call_later(
+                time_limit,
+                self.set_status,
+                CommandStatus.TIMEDOUT,
+            )
+
     @property
     def status(self) -> CommandStatus:
         """Returns the status."""
@@ -181,6 +195,11 @@ class BaseCommand(
 
         assert self.status
 
+        # Don't do anything if the command is done. This means the command
+        # finished before the timeout happened.
+        if status == CommandStatus.TIMEDOUT and self.done():
+            return self
+
         if self.status.is_done:
             raise RuntimeError("cannot modify a done command.")
 
@@ -219,6 +238,8 @@ class BaseCommand(
             # If the command is done, set the result of the future.
             if self._status.is_done and not self.done():
                 self.set_result(self)
+                if self._timer_handler:
+                    self._timer_handler.cancel()
 
             # Set the status watcher
             if self.watcher is not None:
